@@ -1,6 +1,6 @@
 package Aniki::Row {
     use namespace::sweep;
-    use Mouse;
+    use Mouse v2.4.5;
     use Carp qw/croak/;
 
     has table_name => (
@@ -123,18 +123,21 @@ package Aniki::Row {
 
     our $AUTOLOAD;
     sub AUTOLOAD {
-        my $self   = shift;
+        my $invocant = shift;
         my $column = $AUTOLOAD =~ s/^.+://r;
-        if (exists $self->row_data->{$column}) {
-            return $self->get($column);
-        }
-        elsif ($self->relationships && $self->relationships->get_relationship($column)) {
-            return $self->relay($column);
-        }
-        else {
-            my $msg = sprintf q{Can't locate object method "%s" via package "%s"}, $column, ref $self;
-            croak $msg;
+
+        if (ref $invocant) {
+            my $self = $invocant;
+            if (exists $self->row_data->{$column}) {
+                return $self->get($column);
+            }
+            elsif ($self->relationships && $self->relationships->get_relationship($column)) {
+                return $self->relay($column);
+            }
         }
+
+        my $msg = sprintf q{Can't locate object method "%s" via package "%s"}, $column, ref $invocant || $invocant;
+        croak $msg;
     }
 };
 
